@@ -1,11 +1,11 @@
 #  Telethroid - Telegram BoT Library for Python
 #  Copyright (C) 2023-present Pr0fess0r-99 <https://github.com/Pr0fess0r-99>
 
-__version__ = "0.0.25"
+__version__ = "0.0.26"
 __license__ = "GNU Lesser General Public License v3.0 (LGPL-3.0)"
 __copyright__ = "Copyright (C) 2023-present Pr0fess0r-99 <https://github.com/Pr0fess0r-99>"
 
-from Telethroid.clients import TelethroidClient
+from Telethroid.client.telethroid import TelethroidClient
 
 def started_telethroid():
   print(
